#include "main.ih"
#include "VERSION"

char version[] = VERSION;
char year[] = YEARS;
